@@ -12,6 +12,8 @@
  * of setting the windows titles in the future..
  */
 
+#ifndef GNOME_DISABLE_DEPRECATED
+
 #ifndef GNOME_WINDOW_H
 #define GNOME_WINDOW_H
 
@@ -28,3 +30,5 @@ void gnome_window_toplevel_set_title (GtkWindow *window,
 G_END_DECLS
 
 #endif /* GNOME_WINDOW_H */
+
+#endif /* GNOME_DISABLE_DEPRECATED */
